#!/bin/sh
# test we are root
if [ "$(id -u)" != "0" ]; then
   echo "run as root now exitting"
   exit 1
fi

export CFLAGS="-march=armv8-a+crc -mtune=cortex-a72 -Os -pipe"
export CXXFLAGS="-march=armv8-a+crc -mtune=cortex-a72 -Os -pipe -fno-exceptions -fno-rtti"

P=groff
V=1.22.4
SRC=$P-$V
USER=`cat /etc/sysconfig/tcuser`
LIST="compiletc submitqc perl5 ghostscript  "
for Z in $LIST
    do 
    su -c "tce-load -i $Z" $USER
done

cd /usr/local/lib
rm -rf *.la
rm -rf gcc/aarch64-unknown-linux-gnu/12.2.0/plugin/*.la
rm -rf gcc/aarch64-unknown-linux-gnu/12.2.0/*.la
rm -rf gprofng/*.la 
rm -rf python3.8/site-packages/*.la
rm -rf pkcs11/*.la
rm -rf cairo/*.la
rm -rf gtk-2.0/modules/*.la
rm -rf gtk-2.0/2.10.0/printbackends/*.la
rm -rf gtk-2.0/2.10.0/immodules/*.la
rm -rf gtk-2.0/2.10.0/engines/*.la
rm -rf imlib2/loaders/*.la
rm -rf imlib2/filters/*.la
rm -rf gdk-pixbuf-2.0/2.10.0/loaders/*.la
rm -rf libnl/cli
cd /tmp
rm -rf /usr/lib/*.la

su -c "/usr/local/bin/wget -nc --no-check-certificate \
http://ftp.gnu.org/gnu/$P/$SRC.tar.gz"  $USER
tar xvf $SRC*gz
cd $SRC
./configure --prefix=/usr/local --with-doc=no 
# Prefix: /usr/local
# Compiler: gcc -march=armv8-a+crc -mtune=cortex-a72 -Os -pipe 
# X11 support                     : no
# Doc build                       : no
# URW fonts for pdf               : no
# Use uchardet library for preconv: no
# pdftools for distcheck          : no
make -j4 # 1M15s
make install-strip DESTDIR=/tmp/$P
cd /tmp

# main
#######
rm -rf  $P/usr/local/share/man
mkdir -p $P/usr/local/share/doc/$P
echo 'GPL v3 ' >  $P/usr/local/share/doc/$P/COPYING	
cp $SRC/LICENSES $P/usr/local/share/doc/$P/

# TCZ them
###########
LIST2="$P "
for Z in $LIST2
do
	mksquashfs $Z $Z.tcz
	md5sum $Z.tcz > $Z.tcz.md5.txt
	cd $Z
	find usr -not -type d > /tmp/$Z.tcz.list
        sed 's|usr|/usr|g' -i /tmp/$Z.tcz.list
	cd /tmp
done

ls -hal

echo 'Title:          groff.tcz
Description:    text format tool 
Version:        1.22.4
Author:         groff Team
Original-site:  http://ftp.gnu.org/gnu/groff
Copying-policy: read LICENSES 
Size:           2.7M
Extension_by:   aus9
Tags:           man page 
Comments:       mainly for man-page viewing
                
Change-log:     2023/06/27 v 1.22.4 on 14.x
Current:        2023/06/27' > $P.tcz.info

# ignore perl scripts # delete duplicates TCBs below 
readelf -d $P/usr/local/bin/troff | grep 'NEEDED'  
# no extras for addftinfo,eqn,grn,grodvi,grolbp,grolj4,grops,
# grotty,hpftodit,lkbib,lookbib,pfbtops,pic,post-grohtml.pre-grohtml,
# preconv,refer,soelim,tbl,tfmtodit 

echo 'perl5.tcz' > $P.tcz.dep

submitqc --libs
rm -rf *.zsync*


